@@ -151,6 +151,18 @@ pub struct Procedure {
     pub mqtt: String
 }
 
+#[derive(Clone, Debug, Deserialize, Serialize)]
+pub struct ProcedureItem {
+    pub id: String,
+    pub name: String,
+    pub description: String,
+    pub assignedid: String,
+    pub systemtype: String,
+    pub samplingTime: SamplingTime,
+    pub observedproperties: Vec<Output>,
+    pub offerings: Vec<String>
+}
+
 // #[derive(Clone, Serialize, Deserialize, Debug)]
 // pub enum OutputData {
 //     Procedure
@@ -172,6 +184,14 @@ pub struct DataResultGO {
     pub total: i32
 }
 
+#[derive(Clone, Serialize, Deserialize, Debug)]
+pub struct DataResultGetProcedures {
+    pub success: bool,
+    pub message: String,
+    pub data: Vec<ProcedureItem>,
+    pub total: i32
+}
+
 // INSERT OBSERVATION
 
 #[derive(Clone, Debug, Deserialize, Serialize)]
@@ -473,4 +493,25 @@ pub async fn oxygen_saturation_corrected(
     let cf = ((pressure * 0.0987)-0.0112)/100.0;
     let os = oxygen_saturation * cf;
     Ok(os)
+}
+
+pub async fn get_procedures(
+    url: &str,
+    auth: &str
+) -> Result<Vec<ProcedureItem>, Box<dyn std::error::Error>> {
+    let client = reqwest::Client::new();
+    let res = client
+        .get(url)
+        .header(
+            reqwest::header::AUTHORIZATION,
+            auth
+        )
+        .send()
+        .await?;
+
+    let t = res
+        .text()
+        .await?;
+    let go: DataResultGetProcedures = serde_json::from_str(&t).unwrap();
+    Ok(go.data)
 }
\ No newline at end of file
